---
title: "Thomas Kuhn, Revolutions, Paradigms, and Progress"
date: 2022-04-21T19:13:39+01:00
tags: ["revolution","progress","telology","truth"]
topics: ["metaphysics", "epistemology", "sociology", "science"]
image: img/thomas-kuhn-hero-image.jpg
description: Measuring progress across paradigms is possible, but not if you're a scientist.
draft: false
---
## The Problem of Progress

The question I'm addressing today, is on Thomas Kuhn's Structure of Scientific Revolutions. It was posed to me recently, in this form: "*Is Kuhn right that we cannot speak of progress across scientific paradigms?*" This paper will briefly summarize Kuhn's own definition of progress both within and across paradigms, explore the implications of these definitions, and assess the conclusion Kuhn comes to at the end of Chapter XIII of The Structure of Scientific Revolutions. The overall argument of this paper is that the initial question is misleading when compared to what Kuhn actually argues, but that Kuhn is still mistaken in his rejection of the notion of progress because elsewhere he admits himself that incommensurability does not deny the possibility of measurement, and because the analogy to evolution is fundamentally flawed. The paper will conclude with a few summary remarks about progress, both as it relates to science, and as a general concept.

To begin with, a note of clarity is necessary on the question. Kuhn did not say that "we cannot speak of progress" across scientific paradigms. What he said, was that the '*usual answers*' to the question of why "progress is a perquisite reserved almost exclusively for... science"[^1] had been denied by his essay, and secondly, that "we may... have to relinquish the notion... that changes of paradigm carry scientists... closer and closer to the truth".[^2] However, Kuhn suggested that substitute explanations of progress may yet be found. What's more, he says that 'science' is a term that is "reserved for fields that *do* progress in obvious ways", and that he is "a convinced believer in scientific progress."[^3]

So, according to Kuhn, talking about progress across paradigms *is* possible, but what is not possible, according to Kuhn, is two-fold: first, the usual answers to the question of what constitutes progress won't suffice to explain progress across paradigms as he has described them in his book, and second, that it's not possible to speak of progress *as an intentional movement toward truth* when considering changes across paradigms. Those two assertions significantly narrow the scope of Kuhn's conclusions, because now we're not debating progress *in general*, but a certain kind of progress. And he's not foreclosing possibility, but simply arguing that the present talk of progress is mistaken.  The task, then, is to decide whether or not Kuhn is correct about these two definite conclusions. To accomplish that task, we must first discover what Kuhn means by progress.

## Defining Progress 
Kuhn's first definition of progress limits it to *within* paradigms. Progress within a paradigm is something like the gradual accumulation of successful articulations, extensions, and refinements of the given paradigm. In other words, from the worldview supplied by the given paradigm, progress would constitute an accumulation of ever more sophisticated ways of describing and manipulating nature. This picture is very similar to the 'usual answer' picture, in that it assumes a cumulative understanding of science - the collective accretion of knowledge across time, derived from scientific investigation and experimentation.

Intra-paradigm progress differs in one very significant way from the traditional view of science. The 'usual answer' picture assumes an epistemology that puts man in the position of judging his own understanding of reality. But, Kuhn insists, paradigms are not unfiltered contact with objective reality (whatever that might be). They are interpretive frameworks within which we make sense of the phenomenal experience provided by reality, supplying both the way in which experiential data is collected, and the tools by which we process that data into some kind of explanatory web of knowledge. Rather than putting us closer to reality, then, a paradigm imposes a filter through which sense-making is made possible.

What's more, Kuhn says that the cumulative view of intra-paradigm progress is not possible across paradigms, because the paradigms are 'incommensurable'. This term does not mean 'incomparable', but rather incompatible in the terms constitutive of each of the competing paradigms. This incompatibility does not make inter-paradigm comparison impossible, but it does render the notion of linear progress impossible. We will address the issue of linear progress in a moment, but Kuhn offers a nice clarification of incommensurability in The Road Since Structure:

> *Most or all discussion of incommensurability have depended upon the literally correct but regularly over-interpreted assumption that, if two theories are incommensurable, they must be stated in mutually untranslatable languages... applied to the conceptual vocabulary deployed in and around a scientific theory, the term 'incommensurability' functions metaphorically. The phrase 'no common measure' becomes 'no common language'. The claim that two theories are incommensurable is then the claim that there is no language, neutral or otherwise, into which both theories, conceived as sets of sentences, can be translated without  residue or loss. No more in its metaphorical than its literal form does incommensurability imply incomparability, and for much the same reason...*[^4]

One practical example that might be offered as a way to conceptualize this, might be to imagine the same calculator application running on two different computers with alien architectures: An IBM 1401 analog computer and an Apple //e 8bit digital computer are both capable of solving complex math problems (given appropriate programming and data inputs), but it is impossible to understand what the 1401 is doing from the point of view of an Apple //e programmer and vice-versa. Even an objective analysis of each of the platforms (say, in terms of power consumption under certain calculation loads, or in terms of circuit efficiency, or perhaps data bandwidth) would require imposing analog standards of measurement on a digital computer, or digital standards on an analog computer. It's not that the two are incomparable. There are calculation loads, circuits, and data buses that can be measured on the two platforms. But those terms are only *analogous* between the two platforms. An accumulator in the 1401 is not the same thing as an accumulator in an Apple //e. And yet, one could run accumulator calculations on either machine, just the same.

What then, does Kuhn mean when he discusses progress across paradigms? First, he says that the transition to a new paradigm occurs only when the new paradigm contains a solution to an existing puzzle that the present paradigm cannot solve. Second, he says that the new paradigm must provide the *promise* to resolve additional problems that arose as a result of the resolved anomaly[^5]. In short, progress occurs when the new paradigm "is a better instrument for discovering and solving puzzles"[^6] than the old paradigm.

In the case of our two imaginary computers, we might say that progress has been made when it can be shown that the new digital 'paradigm' can out-perform the analog 1401 in some problem-solving meta-operation, for example, being able to do accumulations on floating-point numbers, rather than just integers. Note, however, that we need not actually *know* what's going on *inside* the 1401 or the Apple //e. We can devise tests that satisfy whatever criteria we want: blocks of addition problems, subtraction problems, variable substitutions, differential equations (or whatever), and simply measure the results. Which one calculated faster? Which one calculated more accurately? Which one was able to execute more calculations? And so forth. If the newer machine outperformed the older one, then progress has been achieved.

This metaphor seems consistent with Kuhn's idea of progress across paradigms, understood as a "better instrument for problem-solving", because we need not concern ourselves with the underlying workings of the machines. Only with their *effects*. Indeed, Kuhn says that the reason progress in science is not possible in the ontological sense, is because there can be no "objective" vantage-point from which two different ontological models of reality in two paradigms could be compared directly with each other, let alone with nature itself (any observation of nature would require entering into an ontological paradigm). The only thing we can universalize, is our capacity to experience and observe (expressing those observations, though, would of course again trap us in an ontological paradigm in order to communicate). So, the only way you could compare two paradigms, is by observing their *effects*, and judging those effects against a standard like problem-solving capacity -- and both the number, and kinds of solutions produced as effects of a new paradigm would count against, or in favor of, that paradigm.

## Analyzing the Implications

If the metaphor of computing architectures is apt, then it raises two difficulties. First, if we have no knowledge of what's going on inside either computer, then how in the world would we manage to get the appropriate programs and data into the machines in the first place? If I don't know what programming languages are available, how to construct programs in those languages, how to get those programs compiled and schedule for execution, and how to read the results (or even where to find the results), how could I run calculations on either of them? For that matter, why would I assume these black boxes were even capable of calculation in the first place? They might heat up the room, make noises, and blink or flash, or spit out paper with symbols on them. But what makes it possible for me to interact coherently with either machine in the absence of some sort of reductive understanding of their inner workings?

Once I had such an understanding, even if rudimentary, why wouldn't it be possible for me to improve that understanding by exploration of the machine? Examining its circuits, experimenting with different power sources, swapping out components, and so forth. So that, indeed, I would have "a better representation of what [the machine] is really like", that I could convey to others in a textbook. If such an understanding was not possible, then the machine would forever remain a black box to me. Likewise with science, nature would have remained a complete mystery to us. Yet, we seem at least imperfectly capable of reverse-engineering the black box that is nature, and that reverse-engineering seems to be getting more effective over time, regardless of the paradigm involved. Which strongly suggests cross-paradigm progress at the ontological level.

The second difficulty is perhaps even more significant, and goes to the core of this essay. Kuhn says that the "unit of scientific achievement is the solved problem."[^7] He also talks a great deal in this book about how paradigms  and theories are selected. But he does not fully address the question of how we select *problems* (apart from an attempt to differentiate social sciences from the 'natural' sciences and to describe how problem-solution *sets* will increase in size and complexity with the new specializations that come with new paradigms). This observation is important, because it goes to something he says later about the "developmental process" across paradigms:

> *The developmental process described in this essay has been a process of evolution from primitive beginnings -- a process whose successive stages are characterized by an increasingly detailed and refined understanding of nature -- But nothing that has been or will be said makes it a process of evolution toward anything. We are all deeply accustomed to seeing science as the one enterprise that draws constantly nearer to some goal set by nature in advance. But need there be such a goal?*[^8]

Kuhn answers this question by proposing the parallel of the metaphor of natural selection in biology. Darwin was trying to explain the diversity of species, and proposed the concept of a selection mechanism in nature, derived from local environmental pressures and reproductive success. Kuhn seems, at this late stage of the book, to be attempting to account for the plurality of scientific fields by way of the propagation of paradigms across the whole of science. This attempt at an explanation of academic diversity is not fleshed out well in the book (much of it is simply implied in prior chapters). But the more important point, is that he wants to say that the notion of "progress toward" an ideal goal is as unnecessary in his paradigm view of science, as it is in Darwin's natural selection view of biology. Living beings exist, they are impacted by the environment, and they propagate into the future. The extent to which environmental impact reduces the living being's capacity to reproduce, is the extent to which the species is limited. Random mutations will either increase or diminish reproductive fitness, and that will in turn increase or diminish the propagation of the species. Likewise, with paradigms. They exist, they are impacted by the experimental environment, and they propagate into the future. The extent to which experimental environment impact reduces a paradigm's capacity to reproduce itself, is the extent to which the paradigm is limited. Anomalies accumulate in a paradigm and the capacity or failure to resolve the anomaly will increase or diminish the propagation of the paradigm.

This reduces the scientific endeavor, as a collective knowledge production enterprise, to an unconscious mechanical process. This wouldn't be a problem if we were talking about actual computers (rather than metaphorical ones), or Darwin's Finches. But the question is precisely the satisfaction of the human *desire to know* (as Aristotle put it). If individual scientists are making conscious choices about what problems to work on, then they are engaged in value judgments. Value judgments are based on either utilitarian goals or deontic principles at which we aim. That necessarily introduces the element of *telos* back into the equation: the end of knowledge.

Since no man operates in isolation -- not even (perhaps especially not even) the scientist -- the decision about what problems to tackle are complicated by an intricate web of social factors: moral commitments, social obligations, professional goals, and institutional pressures. All of this is going to end in the scientist making a value judgment compounded of numerous ingredients, and reflective of the society in which he is working. Thus, it is not simply a quantitative question we have to ask about the "problem-solving" of a paradigm, but also a qualitative question of *what kind* of problems will be included in the set of possibilities, and that can only be answered by asking what we *want*, and that is going to be determined by what we value, and that will give us our *telos*.

But if Kuhn is right, and there is no *telos*, and as such, no end point against which we can measure whether our scientific work is getting us there or not, then he is correct that there is no sense in which progress could be measured, at least across paradigms if not within them. But if that were the case, then we wouldn't much care about solving problems, and the question then becomes, what *is* science *doing*, if it is *not* progressing? Are scientists just a large population of humans, busying themselves with an intellectual fetish that scratches some cognitive itch until they die? I would argue this is not the case  -- and Kuhn himself insisted that he was a convinced believer in scientific progress. So, what else is going on here?

Kuhn admits that we move steadily *from* "primitive beginnings". But he insists that we are not moving *toward* a goal. However, to move steadily away from some starting point, is necessarily to move *toward* something else. You may not consciously have chosen that something else. But it is there, nonetheless. To refer back to the Darwin analogy, human evolution is human evolution, precisely because the organisms that lead up to humans were not just "moving away" from the "primitive", but moving *toward* a form that *best fit a particular environment*. Australopithecine leaders did not club together, and hand-pick the sexual matings that would eventually lead to Homo Habilis and Homo Erectus, and yet, came Homo Erectus! How is that possible? There was no goal!

To put this mistake another way: evolutionary biologists will tell you any notion of a goal is an epiphenomenal illusion at best (the way a gyroscope looks like a sphere, when its spinning). But it is still the case that primates have evolved ever more sophisticated and complex ways of interacting with, and directly manipulating, their environment -- and one such primate is now somehow able to look backward, and recognize the difference between 'primitive beginnings', and the 'more advanced' present. It is unclear why one should reject the recognition of this directionality, simply because it is not obviously the direction set by a single consciousness. In short, teleology need not imply eschatology.

In the same way, scientific work is goal-directed, whether we realize it or not. We just haven't been looking in the right place for the goal, for a very long time. The best analogy for this might be the Hayekian view of the free market. Planned economies never work, because there are simply too many variables to account for, and because no single ruler can ever construct a goal that is coherent enough to be achievable by all of his people with any scalable success. But if your desire is to maximize the rational efficiency of the distribution of available resources across a population, then the best option is to let each individual determine for himself the value of each resource locally. In doing so, you enable a highly complex set of calculations by distributing them across the entire population. One side effect of such a policy, is the general increase of wealth across the population. Even if the policy does nothing to flatten distributions (something that is often erroneously assumed in the notion of economic 'efficiency'), it is still the case that the poorest are better off than the poorest in command economies. The point here, is not a defense of the free market, but rather to suggest that it is no less reasonable to see in the movement of humanity from one set of conditions to another across history as teleological, as it is to see it as an aggregation of accidental efficient causes.  Just as it is no less reasonable to see Kuhn's gestalt image as either a duck or a rabbit.

To summarize, science cannot properly cope with a concept like *telos*, because it is coming from the wrong end of the causal continuum. In Aristotelian terms, science is primarily concerned with *efficient* causes. Efficient causes are "push" causes -- causes that come from below, or before (so to speak), an effect in the present. These words are appearing on this page because my fingers are pressing buttons, the buttons are actuating electrical circuits, those circuits are changing states in a processor, the processor is loaded with instructions, and so on, down the line, to an originating cause like the Big Bang. Science can see efficient causes (and really, only efficient causes), because it's tools are especially tuned to see them. As David Hume put it, regular impressions on the mind, pressed there by our senses, and organized into patterns of "constant conjunctions", allow us to understand *how* a billiard ball got from point A to point B.

But *final* causes are not like this at all. Final causes are "pull" causes. They come from *above* or *after* (so to speak) an effect in the present (dare I say, they *supervene* on the present). There is no methodology or mechanism in science for detecting, measuring, or probing the nature or origin of a final cause. It must be noticed in other ways.  Admittedly, this is a metaphysical claim, not a physical one. So, it would be unreasonable to expect science to be equipped with such tools. But to argue that because science cannot see a part of reality it is necessarily an illusion, is to assert that science is the only discipline that is capable of arriving at something like knowledge. This is something Kuhn himself at least implicitly rejects, insisting in Structure:

> *No creative school recognizes a category of work that is, on the one hand, a creative success, but is not, on the other, an addition to the collective achievement of the group. If we doubt, as many do, that nonscientific fields make progress, that cannot be because individual schools make none. Rather, it must be because there are always competing schools, each of which constantly questions the very foundations of the others. The man who argues that philosophy, for example, has made no progress emphasizes that there are still Aristotelians, not that Aristotelianism has failed to progress*.[^9]

So, it may indeed be the case that there is progress -- and progress with a definite direction -- across paradigms, but science would simply not be equipped with the tools necessary to measure it. An appeal to philosophy, theology, or some other discipline might be required, to do so. If that is the case, then Kuhn would be correct in one sense, to say that progress cannot be 'talked about' across paradigms, but it would be for a reason entirely foreign to his own argument, and only in a narrow sense: *science itself* would not be able to 'talk about' progress across scientific paradigms, but plenty of other disciplines might well indeed be able to.

## Conclusion 

The focus of this paper has been on a notion of progress *as a movement toward truth*, and whether or not science -- more specifically, the transitional cycle of Kuhn's scientific paradigms -- is accomplishing that movement. Kuhn's claim is not that it is not making progress, but rather, that the progress it is making is not *this kind* of progress. Rather than movement toward truth, Kuhn substitutes his own notion of improvements in problem-solving capacity as the standard of progress. But, as we have seen, it makes little sense to talk of problem-solving without talking about truth, in some sense, and a movement toward it. If we are to agree that the human being is indeed more than simply a primate with an oddly peculiar itch it continually scratches, then problems (or 'puzzles', as he alternately called them) imply an end goal. Problems are obstacles in the way of accomplishing that goal. In the particular sense, this could just mean scratching an itch, or it could mean achieving some creative end. If we accept that at least some human beings are pursuing creative ends, then we must admit that there is a kind of progress that has a scope beyond solutions to puzzles that impede those creative ends.

[^1]: Structure (50th Anniversary Edition), Pg. 160

[^2]: Structure (50th Anniversary Edition), Pg. 170

[^3]: Structure (50th Anniversary Edition), Pg. 205

[^4]: The Road Since Structure, Pp. 35-36

[^5]: Taken from James A. Marcum's "Thomas Kuhn's Revolutions", Pg. 71

[^6]: Structure (50th Anniversary Edition), Pg. 206

[^7]: Structure (50th Anniversary Edition), Pg. 169

[^8]: Structure (50th Anniversary Edition), Pg. 170

[^9]: Structure (50th Anniversary Edition), Pg. 162

